import type { ILexer } from './monarch/monarchCommon';
/** A mutable, shallow, and copyable `Array<string>` stack. */
export interface MonarchStack {
    /** The current state of the stack. */
    state: string;
    /** The total depth of the stack. */
    depth: number;
    /** The stack as it was before the current state. */
    parent: MonarchStack;
    /** Returns a clone of the internal stack, which is just an array of strings. */
    serialize(): string[];
    /** Returns a clone of the stack. */
    clone(): MonarchStack;
    /** Adds a new state to the stack. */
    push(state: string): void;
    /** Switches to a new state in the stack. */
    switchTo(state: string): void;
    /** Removes the last state in the stack. */
    pop(): void;
    /** Removes all states in the stack, except for the first. */
    popall(): void;
}
/** Creates a new `MonarchStack` object. */
export declare function createMonarchStack(start: string[]): MonarchStack;
/** Compares two stacks and returns if they are equal.
 *  They can be pure `MonarchStack` objects or already serialized. */
export declare function stackIsEqual(stack1: string[] | MonarchStack, stack2: string[] | MonarchStack): boolean;
export interface MonarchToken {
    /** The type of the token. */
    type: string;
    /** The position of the start of the token, relative to the line it's on. */
    start: number;
    /** The position of the end of the token, relative to the line it's on. */
    end: number;
    opens: string | false;
    closes: string | false;
}
export interface TokenizeOpts {
    /** The line to be tokenized. */
    line: string;
    /** The (already compiled) Monarch lexer configuration. */
    lexer: ILexer;
    /** The `MonarchStack` that the tokenizer will begin with. */
    stack: MonarchStack;
    /** The offset from the start of the line that the tokenizer will begin from. */
    offset?: number;
}
/** Returns the tokens for the given line. Mutates the `opts.stack` `MonarchStack` object. */
export declare function tokenize(opts: TokenizeOpts): {
    stack: MonarchStack;
    tokens: MonarchToken[];
};
